library(Seurat)
library(dplyr)

Full_final <- readRDS("/DATA/31/molteni/vexas_sorted_4/results/Full/01-seurat/Full_final.rds")

# computation on cluster numbers 
# res 0.6

setwd("/DATA/31/molteni/vexas_sorted_4/results/DE_markers_06/")
Idents(Full_final)<-"RNA_snn_h.orig.ident_res.0.6"

clusters <- levels(Full_final@meta.data$RNA_snn_h.orig.ident_res.0.6)


for(i in 0:length(clusters)) {
  markers <- FindMarkers(Full_final, ident.1 = "Pool_A_h", group.by = "orig.ident", subset.ident = i)
  markers['cluster'] <- i
  filename=paste("markers_cluster_",i,".csv", sep="")
  write.csv(markers, file=filename)
}

df <- list.files(path='/DATA/31/molteni/vexas_sorted_4/results/DE_markers_06/') %>% 
  lapply(read.csv) %>% 
  bind_rows

df <- df[df$p_val_adj<0.05,]
setwd("/DATA/31/molteni/vexas_sorted_4/results/summary/")

write.csv(df, file="PoolA_hvsPoolB_h_sigMarkers_06.csv")
cells_by_sample <- table(Full_final@meta.data$RNA_snn_h.orig.ident_res.0.6, Full_final@meta.data$orig.ident)
write.csv(cells_by_sample, file="cells_bysample.csv")

cc_distribution <-as.data.frame (table(Full_final$Phase, Full_final$orig.ident, Full_final$RNA_snn_h.orig.ident_res.0.6))
colnames(cc_distribution) <- c("Phase","orig.ident","cluster","CellNumb")
write.csv(cc_distribution, file="cell_cycle_06.csv")

### res 1.2
setwd("/DATA/31/molteni/vexas_sorted_4/results/DE_markers_12/")

Idents(Full_final)<-"RNA_snn_h.orig.ident_res.1.2"

clusters <- levels(Full_final@meta.data$RNA_snn_h.orig.ident_res.1.2)

for(i in clusters) {
  cells_group1 = sum(Full_final$orig.ident == "Pool_A_h" & Full_final$RNA_snn_h.orig.ident_res.1.2 == i)
  cells_group2 = sum(Full_final$orig.ident == "Pool_B_h" & Full_final$RNA_snn_h.orig.ident_res.1.2 == i)
  if(cells_group1 >= 3 & cells_group2 >= 3 ) {
    markers <- FindMarkers(Full_final, ident.1 = "Pool_A_h", group.by = "orig.ident", subset.ident = i)
    markers['cluster'] <- i
    filename=paste("markers_cluster_",i,".csv", sep="")
    write.csv(markers, file=filename)
  }
  else {
    print(paste("Skipping comparison for", i, "due to insufficient cell count in one or both groups."))
  }
}


df <- list.files(path='/DATA/31/molteni/vexas_sorted_4/results/DE_markers_12/') %>% 
  lapply(read.csv) %>% 
  bind_rows

df <- df[df$p_val_adj<0.05,]

setwd("/DATA/31/molteni/vexas_sorted_4/results/summary/")
write.csv(df, file="PoolA_hvsPoolB_h_sigMarkers_12.csv")
cells_by_sample <- table(Full_final@meta.data$RNA_snn_h.orig.ident_res.1.2, Full_final@meta.data$orig.ident)
write.csv(cells_by_sample, file="cells_bysample_12.csv")

cc_distribution <-as.data.frame (table(Full_final$Phase, Full_final$orig.ident, Full_final$RNA_snn_h.orig.ident_res.1.2))
colnames(cc_distribution) <- c("Phase","orig.ident","cluster","CellNumb")
write.csv(cc_distribution, file="cell_cycle_12.csv")

###############################################################################################################


# computation on custom annotation

setwd("/DATA/31/molteni/vexas_sorted_4/results/DE_markers/AvsB/")
Full_final <- readRDS("/DATA/31/molteni/vexas_sorted_4/results/Full/01-seurat/Full_final_annot.rds")

clusters <- unique(Full_final@meta.data$celltypes_annot)

for(i in clusters) {
  markers <- FindMarkers(Full_final, ident.1 = "Pool_A_h", group.by = "orig.ident", subset.ident = i)
  markers['cluster'] <- i
  filename=paste("markers_cluster_",i,".csv", sep="")
  write.csv(markers, file=filename)
}

df <- list.files(path='/DATA/31/molteni/vexas_sorted_4/results/DE_markers/AvsB/') %>% 
  lapply(read.csv) %>% 
  bind_rows

df <- df[df$p_val_adj<0.05,]
setwd("/DATA/31/molteni/vexas_sorted_4/results/summary/")

write.csv(df, file="PoolA_hvsPoolB_h_sigMarkers.csv")
cells_by_sample <- table(Full_final@meta.data$celltypes_annot, Full_final@meta.data$orig.ident)
write.csv(cells_by_sample, file="cells_bysample.csv")

cc_distribution <-as.data.frame (table(Full_final$Phase, Full_final$orig.ident, Full_final$celltypes_annot))
colnames(cc_distribution) <- c("Phase","orig.ident","cluster","CellNumb")
write.csv(cc_distribution, file="cell_cycle.csv")

